@@ -18,8 +18,6 @@ xmlWriteTag (fid, 'Ppath', []);
 
 xmlWriteIndex (fid, fidb, data.dim, precision);
 xmlWriteIndex (fid, fidb, data.np, precision);
-xmlWriteIndex (fid, fidb, data.refraction, precision);
-xmlWriteString (fid, fidb, data.method, precision);
 xmlWriteNumeric (fid, fidb, data.constant, precision);
 xmlWriteMatrix (fid, fidb, data.pos, precision);
 xmlWriteVector (fid, fidb, data.z, precision);
@@ -31,10 +29,7 @@ xmlWriteMatrix (fid, fidb, data.los, precision);
 xmlWriteString (fid, fidb, data.background, precision);
 xmlWriteVector (fid, fidb, data.tan_pos, precision);
 xmlWriteVector (fid, fidb, data.geom_tan_pos, precision);
-xmlWriteVector (fid, fidb, data.p, precision);
-xmlWriteVector (fid, fidb, data.t, precision);
-xmlWriteMatrix (fid, fidb, data.vmr, precision);
-xmlWriteArrayOf (fid, fidb, data.next_parts, 'Index', precision);
+xmlWriteVector (fid, fidb, data.nreal, precision);
 
 xmlWriteCloseTag (fid, 'Ppath');
 
